@@ -237,6 +237,7 @@ public:
 	vector<int> goalState;
 	vector<int> state;
 	GymReturn gymReturn;
+	bool done;
 	Names n;
 
 	ProtossMacroEnv() {
@@ -406,6 +407,7 @@ public:
 		gymReturn.done = isDone();
 		gymReturn.state = state;
 		reward = -timeToAction;
+		done = isDone();
 	}
 
 	double getTimeNextSupplyDone() {
@@ -669,16 +671,19 @@ PYBIND11_MODULE(probotest1, m) {
         .def(pybind11::init<>())
         .def("step", &ProtossMacroEnv::step)
 		.def("reset", &ProtossMacroEnv::reset)
-		.def("getState", &ProtossMacroEnv::getState)
+		.def("getEntityList", &ProtossMacroEnv::getState)
 		.def("getViableActions", &ProtossMacroEnv::getViableActions)
 		.def("getViableExecutors", &ProtossMacroEnv::getViableExecutors)
 		.def("getViableTargets", &ProtossMacroEnv::getState)
         .def_readwrite("minerals", &ProtossMacroEnv::minerals)
-		.def_readwrite("vespenegas", &ProtossMacroEnv::gas)
+		.def_readwrite("gas", &ProtossMacroEnv::gas)
 		.def_readwrite("time", &ProtossMacroEnv::time)
 		.def_readwrite("supply", &ProtossMacroEnv::supply)
 		.def_readwrite("supplycap", &ProtossMacroEnv::maxSupply)
 		.def_readwrite("reward", &ProtossMacroEnv::minerals)
+		.def_readwrite("probeCountOnMinerals", &ProtossMacroEnv::mProbeCount)
+		.def_readwrite("probeCountOnGas", &ProtossMacroEnv::gProbeCount)
+		.def_readwrite("state", &ProtossMacroEnv::state)
         ;
 
 	pybind11::class_<Names>(m, "Names")
